<?PHP
/**
 * Constains lists for categorizing event types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides a list for finding the respective event type ID for a given event type name.
 */
final class MDConcEventTypes implements MDImporterConcordanceListInterface {

    private const EVENT_TYPE_NAMES_TO_ID = [

        // 1: Created
        'Hergestellt' => 1,
        'Hergestellt vermutlich' => 1,
        'Herstellung' => 1,
        'Herstellung vermutlich' => 1,
        'Production' => 1,
        'production' => 1,
        'Bearbeitung' => 1,
        'Beginning of existence'  => 1,
        'creation'                => 1,
        'Erschaffung/Herstellung' => 1,
        'http://terminology.lido-schema.org/eventType/production' => 1,
        'Leipoldt, J.' => 1,
        'Produktion' => 1,
        'Rohleder, Walter, Reichenbach' => 1,
        // "Unknown event"
        'Aktivität' => 1,
        'http://terminology.lido-schema.org/lido00004' => 1,
        'Ereignis' => 1,
        'http://terminology.lido-schema.org/lido00003' => 1,
        'Herstellung des Abzugs/der Abformung' => 1,

        // 2: Was found
        'Auffinden' => 2,   // Finding
        'Ausgrabung' => 2,  // Excavation
        'Excavation' => 2,
        'Fund' => 2,        // Finding
        'Fund (Aktivität)' => 2,
        'Finding' => 2,
        'Finding (Activity)' => 2,
        'Gefunden' => 2,
        "Виявлення" => 2,
        "Виявленнґ" => 2,
        'Finding
                                (Activity)' => 2,
        'http://terminology.lido-schema.org/lido00002' => 2,
        'Розкопки' => 2,    // Excavation
        'Знахідка' => 2,    // Find

        // 3: Published
        'Published' => 3,
        'Veröffentlicht' => 3,
        'Veröffentlichung' => 3,
        'published' => 3,
        'http://terminology.lido-schema.org/eventType/publication' => 3,
        'Publikation' => 3,
        'Publishing' => 3,
        'Publication' => 3,
        'Publication Event' => 3,
        'Publication (Event)' => 3,

        // 4: Template creation
        'Template creation' => 4,
        'Vorlagenerstellung' => 4,

        // 5: Displayed actor
        'Was displayed (actor)' => 5,
        'Displayed actor' => 5,

        // 6: Was used
        'Aufführung' => 6,
        'Ausstellung' => 6,
        'Ausstellung (Aktivität)' => 6,
        'http://terminology.lido-schema.org/lido00225' => 6,
        'Verwendungsort' => 6,
        'Move of object' => 6,
        'Wurde genutzt' => 6,
        'gebrauch' => 6,
        'Gebrauch' => 6,
        'Use' => 6,
        'http://terminology.lido-schema.org/eventType/use' => 6,
        'Diener' => 6,
        'Digitalisierung' => 6,
        'Дослідження' => 6, // Research
        'Дослідження:' => 6, // Research

        // 7: Written
        'Written' => 7,
        'Geschrieben' => 7,
        'Verfasst' => 7,

        // 8: Collected
        'Collected' => 8,
        'Gesammelt' => 8,
        'Sammeln' => 8,
        'Collecting' => 8,
        'Sammeltätigkeit' => 8,
        'Sammelereignis' => 8,
        'http://terminology.lido-schema.org/lido00010' => 8,
        'Збирання/колекціонування' => 8, // Gathering/collecting
        'Знайдення' => 8,   // Finding
        'знайдення' => 8,   // Finding
        'Передача' => 8,    // Transfer
        'передача' => 8,    // Transfer
        'Привезена' => 8,
        'Передавання' => 8, // Transmission

        // 9: => Painted
        'Painted' => 8,
        'Gemalt' => 8,

        // 10: Recorded
        'Fotografische Aufnahme' => 10,
        'Aufnahme' => 10,
        'Aufgenommen' => 10,
        'Herstellung (Aufnahme)' => 10,

        // '11' => Received
        'Received' => 11,
        'Empfangen' => 11,
        'Отримання' => 11, // Receiving

        // 12 => Printing plate produced
        'Printing plate produced' => 12,
        'Druckplatte hergestellt' => 12,
        'Herstellung der Druckform/Form' => 12,
        'http://terminology.lido-schema.org/lido00484' => 12,

        // '13' => Sent
        'Sent' => 13,
        'Gesendet' => 13,
        'Versendet' => 13,
        'Abgeschickt' => 13,

        // '14' => Issued
        'Issued' => 14,
        'Ausgefertigt' => 14,

        // '15' => Signed
        'Signed' => 15,
        'Unterzeichnet' => 15,

        // '16' => First description
        'First description' => 16,
        'Erstbeschreibung' => 16,
        'Typuszuweisung' => 16,
        'http://terminology.lido-schema.org/lido00023' => 16,

        // '19' => Drawn
        'Drawn' => 19,
        'Gezeichnet' => 19,

        // 20: Copied
        'Copied' => 20,
        'Kopiert' => 20,
        'Abgeschrieben' => 20,

        // 21: Lived
        'Lived' => 21,
        'Gelebt' => 21,

        // 22: Related place
        'Geografischer Bezug' => 22,
        'Geografika' => 22,
        'Karteninhalt' => 22,

        // 25: Commissioned
        'Auftrag' => 25,
        'Commissioning' => 25,
        'Beauftragung' => 25,
        'Beauftragt' => 25,

        // 26 => Printed
        'Printed' => 26,
        'Gedruckt' => 26,

        // 27 => Recorded
        'Recorded song' => 27,

        // 28 => Sung
        'Sung' => 28,
        'Gesungen' => 28,
        'Gesprochen' => 28, // ?

        // 29 => Decor designed
        'Decor designed' => 29,
        'Dekor entworfen' => 29,

        // 30 => Form designed
        'Form designed' => 30,
        'Form entworfen' => 30,

        // 31 => Modelled
        'Modelled' => 31,
        'Modelliert' => 31,

        // 32 => Autographed/Signed
        'Autographed/Signed' => 32,
        'Signiert' => 32,

        // 33 => Mentioned
        'Mentioned' => 33,
        'Wurde erwähnt' => 33,

        // 34 => Buried
        'Buried' => 34,
        'Vergraben' => 34,

        // 35: Intellectual creation
        'Design' => 35,
        'design' => 35,
        'Designing' => 35,
        'Entwerfen' => 35,
        'Entwurf' => 35,
        'Geistige Schöpfung' => 35,
        'Kulturelle Zuschreibung' => 35,
        'Merkmalszuweisung' => 35,
        'http://terminology.lido-schema.org/lido00024' => 35,
        'http://terminology.lido-schema.org/lido00224' => 35,

        // 36 => Was depicted
        // 37 => Painted on
        'Painted on' => 37,
        'Bemalt' => 37,

        // 38 => Illustrated
        'Illustrated' => 38,
        'Illustriert' => 38,

        // 39 => Assembled
        'Assembled' => 39,
        'Was assembled' => 39,
        'zusammengefügt' => 39,
        'Wurde zusammengefügt' => 39,

        // 40 => Auctioned
        'Auctioned' => 40,
        'Was auctioned' => 40,
        'Versteigert' => 40,
        'Wurde versteigert' => 40,

        // 41: Was Bought
        'Erwerb' => 41,
        'Erwerbung' => 41,
        'Acquisition' => 41,
        'Acquisition (Activity)' => 41,
        'http://terminology.lido-schema.org/lido00001' => 41,
        'Bodenreform' => 41,
        'Kauf' => 41,
        'Gekauft' => 41,
        'acquisition_Kauf' => 41,
        'acquisition_Diener' => 41,

        // 42: Owned
        'acquisition_unbekannt' => 42,
        'acquisition_Leipoldt' => 42,
        'acquisition_Mehlig, P.' => 42,
        'acquisition_Krone, Hermann' => 42,
        'acquisition_Schlegel, Charlotte' => 42,
        'acquisition_Schröder' => 42,
        'acquisition_Meier, Th.J.' => 42,
        'acquisition_Schaarschuh, Dresden' => 42,
        'acquisition_Schönfelder, R.' => 42,
        'acquisition_Neumeister' => 42,
        'acquisition_Oehmichen' => 42,
        'acquisition_Photo-Schröder' => 42,
        'acquisition_Rohleder' => 42,
        'acquisition_Mehlig' => 42,
        'Provenienz' => 42,
        'Provenance' => 42,
        'Besessen' => 42,
        'VorbesitzerIn' => 42,
        'http://terminology.lido-schema.org/lido00227' => 42,

        // 43: Was sold
        'was sold' => 43,
        'Verkauft' => 43,
        'Acquisition / Selling' => 43,
        'Vertrieb' => 43,

        // 44: Restorated
        'Restaurierung' => 44,
        'Restauriert' => 44,
        'wurde restauriert' => 44,

        // 45: Damaged
        'Damaged' => 44,
        'Beschädigung' => 44,
        'wurde beschädigt' => 44,

        // 48: Edited
        'Herausgegeben' => 48,

        // 49: Gifted, donated
        'Schenkung' => 49,
        'Nachlass' => 49,
        'Übergabe' => 49,
        'Stiftung' => 49,
        'Donation' => 49,
        'Gespendet / Geschenkt' => 49,
        'acquisition_Schenkung' => 49,
        'acquisition_Nachlass' => 49,
        'acquisition_Übergabe' => 49,
        'acquisition_Stiftung' => 49,
        'acquisition_Bodenreform' => 49,

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return integer
     */
    public static function getConcordanceTarget(string $input):int {

        if (!isset(self::EVENT_TYPE_NAMES_TO_ID[$input])) {
            throw new MDImporterMissingConcordance("Unknown event type: '" . $input . "'");
        }

        return self::EVENT_TYPE_NAMES_TO_ID[$input];

    }
}
