<?PHP
/**
 * Constains lists for categorizing loan types.
 *
 * @author Joshua Ramon Enslin <joshua@museum-digital.de>
 */
declare(strict_types = 1);

/**
 * Provides a list for finding the loan type for an input.
 */
final class MDConcLoanTypes implements MDImporterConcordanceListInterface {

    private const LOAN_TYPES = [

        // Outgoing
        "ausgehend" => "outgoing",

        // Incoming
        "eingehend" => "incoming",

    ];

    /**
     * Require a function for getting the concordance target.
     *
     * @param string $input Input string.
     *
     * @return string
     */
    public static function getConcordanceTarget(string $input):string {

        if (!isset(self::LOAN_TYPES[$input])) {
            throw new MDImporterMissingConcordance("Unknown loan type: " . $input);
        }

        return self::LOAN_TYPES[$input];

    }
}
